@@ -19,8 +19,8 @@
  */
 
 #include <string.h>
-#include <libedataserver/e-sexp.h>
-#include <libedataserver/e-data-server-util.h>
+#include "libedataserver/e-sexp.h"
+#include "libedataserver/e-data-server-util.h"
 #include "e-book-backend-sexp.h"
 
 static GObjectClass *parent_class;
