@@ -27,7 +27,7 @@
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-moniker-util.h>
 #include <glib/gi18n-lib.h>
-#include <libedataserver/e-xml-hash-utils.h>
+#include "libedataserver/e-xml-hash-utils.h"
 #include <libecal/e-cal-recur.h>
 #include <libecal/e-cal-util.h>
 #include <libecal/e-cal-time-util.h>
@@ -113,52 +113,216 @@ struct _ECalBackendCalDAVPrivate {
 	gboolean disposed;
 };
 
-#if 0
+/* ************************************************************************* */
+/* Debugging */
+
+#define DEBUG_MESSAGE "message"
+#define DEBUG_MESSAGE_HEADER "message:header"
+#define DEBUG_MESSAGE_BODY "message:body"
+
+static gboolean caldav_debug_all = FALSE;
+static GHashTable *caldav_debug_table = NULL;
+
+
 static void
-print_header (gpointer name, gpointer value, gpointer data)
+add_debug_key (const char *start, const char *end)
 {
-	g_print ("%s: %s\n", (char *) name, (char *) value);
+	char *debug_key;
+	char *debug_value;
+
+	if (start == end) {
+		return;
+	}
+
+	debug_key = debug_value = g_strndup (start, end - start);
+
+	debug_key = g_strchug (debug_key);
+	debug_key = g_strchomp (debug_key);
+
+	if (strlen (debug_key) == 0) {
+		g_free (debug_value);
+		return;
+	}
+
+	g_hash_table_insert (caldav_debug_table,
+			     debug_key,
+			     debug_value);
+			
+	g_debug ("Adding %s to enabled debugging keys", debug_key);
+}
+
+static gpointer
+caldav_debug_init_once (gpointer data)
+{
+	const char *dbg;
+
+	dbg = g_getenv ("CALDAV_DEBUG");
+
+	if (dbg) {
+		const char *ptr;
+
+		g_debug ("Got debug env variable: [%s]", dbg);
+
+		caldav_debug_table = g_hash_table_new (g_str_hash,
+						       g_str_equal);
+
+		ptr = dbg;
+
+		while (*ptr != '\0') {
+			if (*ptr == ',' || *ptr == ':') {
+			
+				add_debug_key (dbg, ptr);
+
+				if (*ptr == ',') {
+					dbg = ptr + 1;
+				}
+			}
+
+			ptr++;
+		}
+
+		if (ptr - dbg > 0) {
+			add_debug_key (dbg, ptr);
+		}
+
+		if (g_hash_table_lookup (caldav_debug_table, "all")) {
+			caldav_debug_all = TRUE;
+			g_hash_table_destroy (caldav_debug_table);
+			caldav_debug_table = NULL;
+		}
+	}
+	
+	return NULL;
 }
 
 static void
-debug_handler (SoupMessage *msg, gpointer user_data)
+caldav_debug_init ()
 {
-	g_print ("%d %s\nMessage-Debug: %p @ %lu\n",
-                msg->status_code, msg->reason_phrase,
-                msg, time (0));
+	static GOnce debug_once = G_ONCE_INIT;
+  
+	g_once (&debug_once,
+		caldav_debug_init_once,
+		NULL);
+}
 
-	/* print headers */
-	soup_message_foreach_header (msg->response_headers, print_header, NULL);
+static gboolean
+caldav_debug_show (const char *component)
+{
+	if (G_UNLIKELY (caldav_debug_all)) {
+		return TRUE;
+	} else if (G_UNLIKELY (caldav_debug_table != NULL) &&
+		   g_hash_table_lookup (caldav_debug_table, component)) {
+		return TRUE;
+	}
 
-	/* print response */
-	if (msg->response.length) {
-		fputc ('\n', stdout);
-		fwrite (msg->response.body, 1, msg->response.length, stdout);
-		fputc ('\n', stdout);
+	return FALSE; 
+}
+
+static void
+message_debug_print_header (gpointer name, gpointer value, gpointer data)
+{
+	g_debug ("%s: %s", (char *) name, (char *) value);
+}
+
+#define DEBUG_MAX_BODY_SIZE (100 * 1024 * 1024)
+
+static void
+message_response_debug_handler (SoupMessage *msg, gpointer user_data)
+{
+
+	g_debug ("%d %s\nMessage-Debug: %p @ %lu",
+		 msg->status_code,
+		 msg->reason_phrase,
+		 msg,
+		 time (0));
+
+	if (caldav_debug_show (DEBUG_MESSAGE_HEADER)) {
+		/* print headers */
+		soup_message_foreach_header (msg->response_headers,
+					     message_debug_print_header,
+					     NULL);
+
+	}
+
+	if (caldav_debug_show (DEBUG_MESSAGE_BODY)) {
+
+		/* print response */
+		if (msg->response.length) {
+			char *body;
+
+		        //needed for null terminal and truncation	
+			body = g_strndup (msg->response.body,
+					  MIN (msg->response.length,
+					       DEBUG_MAX_BODY_SIZE));
+
+			g_debug ("Response: \n[%s%s]%s", body,
+				 msg->response.length > DEBUG_MAX_BODY_SIZE ?
+				 " ..." : "",
+				  msg->response.length > DEBUG_MAX_BODY_SIZE ?
+				 " (trunkated)" : "");
+
+			g_free (body);
+		}
 	}
 }
 
 static void
-setup_debug (SoupMessage *msg)
+message_setup_debug (SoupMessage *msg)
 {
 	const SoupUri *suri;
 
+	if (G_LIKELY (! caldav_debug_show (DEBUG_MESSAGE))) {
+		return;
+	}
+
 	suri = soup_message_get_uri (msg);
-	g_print ("%s %s%s%s HTTP/1.1\nSOAP-Debug: %p @ %lu\n",
-		 SOUP_MESSAGE (msg)->method, suri->path,
+
+	g_debug ("%s %s%s%s HTTP/1.1\nMessage-ID: %p @ %lu",
+		 SOUP_MESSAGE (msg)->method,
+		 suri->path,
 		 suri->query ? "?" : "",
 		 suri->query ? suri->query : "",
-		 msg, (unsigned long) time (0));
+		 msg,
+		 (unsigned long) time (0));
+
+	soup_message_add_handler (SOUP_MESSAGE (msg),
+				  SOUP_HANDLER_POST_BODY,
+				  message_response_debug_handler,
+				  NULL);
+
+	if (G_LIKELY (! caldav_debug_show (DEBUG_MESSAGE_HEADER))) {
+		return;
+	}
 
 	/* print message headers */
-	print_header ("Host", suri->host, NULL);
-	soup_message_foreach_header (SOUP_MESSAGE (msg)->request_headers, print_header, NULL);
+	message_debug_print_header ("Host", suri->host, NULL);
 
-	soup_message_add_handler (SOUP_MESSAGE (msg), SOUP_HANDLER_POST_BODY, debug_handler, NULL);
+	soup_message_foreach_header (SOUP_MESSAGE (msg)->request_headers,
+				     message_debug_print_header,
+				     NULL);
+
+	if (caldav_debug_show (DEBUG_MESSAGE_BODY)) {
+
+		/* print response */
+		if (msg->request.length) {
+			char *body;
+
+		        //needed for null terminal and truncation	
+			body = g_strndup (msg->request.body,
+					  MIN (msg->request.length,
+					       DEBUG_MAX_BODY_SIZE));
+
+			g_debug ("Request: \n[%s%s]%s", body,
+				 msg->request.length > DEBUG_MAX_BODY_SIZE ?
+				 " ..." : "",
+				  msg->request.length > DEBUG_MAX_BODY_SIZE ?
+				 " (trunkated)" : "");
+
+			g_free (body);
+		}
+	}
 }
-#endif
 
-#define d(x)
 
 static ECalBackendSyncClass *parent_class = NULL;
 
@@ -306,7 +470,7 @@ e_cal_component_set_synch_state (ECalComponent          *comp,
  * use it 
  * and btw FIXME!!! */
 static char *
-e_cal_component_gen_href (ECalComponent *comp, const char *base_uri)
+e_cal_component_gen_href (ECalComponent *comp)
 {
 	char *href, *iso;
 
@@ -314,11 +478,7 @@ e_cal_component_gen_href (ECalComponent *comp, const char *base_uri)
 
 	iso = isodate_from_time_t (time (NULL));
 
-	if (g_str_has_suffix (base_uri, "/")) {
-		href = g_strconcat (base_uri, iso, ".ics", NULL);
-	} else {
-		href = g_strconcat (base_uri, "/" ,iso, ".ics", NULL);
-	}
+	href = g_strconcat (iso, ".ics", NULL);
 
 	g_free (iso);	
 	
@@ -526,6 +686,34 @@ xp_object_get_string (xmlXPathObjectPtr result)
 	return ret;
 }
 
+/* as get_string but will normailze it (i.e. only take
+ * the last part of the href) */
+static char *
+xp_object_get_href (xmlXPathObjectPtr result)
+{
+	char *ret;
+	char *val;
+
+	if (result == NULL || result->type != XPATH_STRING) {
+		return NULL;	
+	}
+
+	val = (char *) result->stringval;
+
+	if ((ret = g_strrstr (val, "/")) == NULL) {
+		ret = val;
+	} else {
+		ret++; /* skip the unwanted "/" */
+	}
+
+	ret = g_strdup (ret);
+	g_debug ("found href: %s", ret);
+	
+	xmlXPathFreeObject (result);
+	return ret;
+}
+
+/* like get_string but will quote the etag if necessary */
 static char *
 xp_object_get_etag (xmlXPathObjectPtr result)
 {
@@ -661,7 +849,7 @@ parse_report_response (SoupMessage *soup_message, CalDAVObject **objs, int *len)
 	
 	*objs = g_new0 (CalDAVObject, n);
 	
-	for (i = 0; i < n;i++) {
+	for (i = 0; i < n; i++) {
 		CalDAVObject *object;
 		xmlXPathObjectPtr xpres;
 		
@@ -669,7 +857,7 @@ parse_report_response (SoupMessage *soup_message, CalDAVObject **objs, int *len)
 		/* see if we got a status child in the response element */
 
 		xpres = xpath_eval (xpctx, XPATH_HREF, i + 1);
-		object->href = xp_object_get_string (xpres);
+		object->href = xp_object_get_href (xpres);
 
 		xpres = xpath_eval (xpctx,XPATH_STATUS , i + 1);
 		object->status = xp_object_get_status (xpres);
@@ -819,6 +1007,20 @@ caldav_set_session_proxy(ECalBackendCalDAVPrivate *priv)
 /* ************************************************************************* */
 /* direct CalDAV server access functions */
 
+static char *
+caldav_generate_uri (ECalBackendCalDAV *cbdav, const char *target)
+{
+	ECalBackendCalDAVPrivate  *priv;
+	char *uri;
+
+	priv = E_CAL_BACKEND_CALDAV_GET_PRIVATE (cbdav);
+
+	/* priv->uri must NOT have trailing slash */
+	uri = g_strconcat (priv->uri, "/" , target, NULL);
+
+	return uri;
+}
+
 static ECalBackendSyncStatus
 caldav_server_open_calendar (ECalBackendCalDAV *cbdav)
 {
@@ -838,7 +1040,7 @@ caldav_server_open_calendar (ECalBackendCalDAV *cbdav)
 	soup_message_add_header (message->request_headers, 
 				 "User-Agent", "Evolution/" VERSION);
 
-	d(setup_debug (message);)
+	message_setup_debug (message);
 	soup_session_send_message (priv->session, message);
 	
 	if (! SOUP_STATUS_IS_SUCCESSFUL (message->status_code)) {
@@ -929,7 +1131,6 @@ caldav_server_list_objects (ECalBackendCalDAV *cbdav, CalDAVObject **objs, int *
 	
 	sn = xmlNewTextChild (node, nscd, (xmlChar *) "comp-filter", NULL);
 	xmlSetProp (sn, (xmlChar *) "name", (xmlChar *) "VEVENT");
-	xmlNewTextChild (sn, nscd, (xmlChar *) "is-defined", NULL);
 	/* ^^^ add timerange for performance?  */
 	
 	
@@ -945,12 +1146,13 @@ caldav_server_list_objects (ECalBackendCalDAV *cbdav, CalDAVObject **objs, int *
 				 "Depth", "1");
 
 	soup_message_set_request (message, 
-				  "text/xml",
+				  "application/xml",
 				  SOUP_BUFFER_USER_OWNED,
 				  (char *) buf->buffer->content,
 				  buf->buffer->use);
 
-	d(setup_debug (message);)
+	message_setup_debug (message);
+
 	/* Send the request now */
 	soup_session_send_message (priv->session, message);
 	
@@ -979,18 +1181,22 @@ caldav_server_get_object (ECalBackendCalDAV *cbdav, CalDAVObject *object)
 	ECalBackendSyncStatus     result;
 	SoupMessage              *message;
 	const char               *hdr;
+	char                     *uri;
 
 	priv = E_CAL_BACKEND_CALDAV_GET_PRIVATE (cbdav);	
 	result = GNOME_Evolution_Calendar_Success;
 
 	g_assert (object != NULL && object->href != NULL);
 	
-	message = soup_message_new (SOUP_METHOD_GET, object->href);
-	
+	uri = caldav_generate_uri (cbdav, object->href);
+	message = soup_message_new (SOUP_METHOD_GET, uri);
+	g_free (uri);
+
 	soup_message_add_header (message->request_headers, 
 				 "User-Agent", "Evolution/" VERSION);
 
-	d(setup_debug (message);)
+	message_setup_debug (message);
+
 	soup_session_send_message (priv->session, message);
 	
 	if (! SOUP_STATUS_IS_SUCCESSFUL (message->status_code)) {
@@ -1033,15 +1239,18 @@ caldav_server_put_object (ECalBackendCalDAV *cbdav, CalDAVObject *object)
 	ECalBackendSyncStatus     result;
 	SoupMessage              *message;
 	const char               *hdr;
-	
+	char                     *uri;
+
 	priv   = E_CAL_BACKEND_CALDAV_GET_PRIVATE (cbdav);	
 	result = GNOME_Evolution_Calendar_Success;
 	hdr    = NULL;
 	
 	g_assert (object != NULL && object->cdata != NULL);
 
-	message = soup_message_new (SOUP_METHOD_PUT, object->href);
-	
+	uri = caldav_generate_uri (cbdav, object->href);
+	message = soup_message_new (SOUP_METHOD_PUT, uri);
+	g_free (uri);
+
 	soup_message_add_header (message->request_headers, 
 				 "User-Agent", "Evolution/" VERSION);
 
@@ -1064,7 +1273,8 @@ caldav_server_put_object (ECalBackendCalDAV *cbdav, CalDAVObject *object)
 				  strlen (object->cdata));
 
 	
-	d(setup_debug (message);)
+	message_setup_debug (message);
+
 	soup_session_send_message (priv->session, message);
 
 	/* FIXME: sepcial case precondition errors ?*/
@@ -1093,13 +1303,16 @@ caldav_server_delete_object (ECalBackendCalDAV *cbdav, CalDAVObject *object)
 	ECalBackendCalDAVPrivate *priv;
 	ECalBackendSyncStatus     result;
 	SoupMessage              *message;
-	
+	char                     *uri;
+
 	priv = E_CAL_BACKEND_CALDAV_GET_PRIVATE (cbdav);	
 	result = GNOME_Evolution_Calendar_Success;
 	
 	g_assert (object != NULL && object->href != NULL);
 
-	message = soup_message_new (SOUP_METHOD_DELETE, object->href);
+	uri = caldav_generate_uri (cbdav, object->href);
+	message = soup_message_new (SOUP_METHOD_DELETE, uri);
+	g_free (uri);
 	
 	soup_message_add_header (message->request_headers, 
 				 "User-Agent", "Evolution/" VERSION);
@@ -1109,7 +1322,8 @@ caldav_server_delete_object (ECalBackendCalDAV *cbdav, CalDAVObject *object)
 					"If-Match", object->etag);
 	}
 	
-	d(setup_debug (message);)
+	message_setup_debug (message);
+
 	soup_session_send_message (priv->session, message);
 	
 	result = status_code_to_result (message->status_code);	
@@ -1335,7 +1549,7 @@ synch_slave_loop (gpointer data)
 		/* Ok here we go, do some real work 
 		 * Synch it baby one more time ...
 		 */
-		d(g_print ("Synch-Slave: Goint to work ...\n"));
+		//d(g_print ("Synch-Slave: Goint to work ...\n")); XXX re-enable output please
 		synchronize_cache (cbdav); 
 
 		/* puhh that was hard, get some rest :) */
@@ -1427,6 +1641,7 @@ initialize_backend (ECalBackendCalDAV *cbdav)
 	GThread			 *slave;
 	const char		 *os_val;
 	const char               *uri;
+	gsize                     len;
 	
 	priv  = E_CAL_BACKEND_CALDAV_GET_PRIVATE (cbdav);
 	
@@ -1448,16 +1663,34 @@ initialize_backend (ECalBackendCalDAV *cbdav)
 	os_val = e_source_get_property(source, "ssl");
 	uri = e_cal_backend_get_uri (E_CAL_BACKEND (cbdav));
 
+
+
 	if (g_str_has_prefix (uri, "caldav://")) {
+		const char *proto;
+
 		if (os_val && os_val[0] == '1') {
-			priv->uri = g_strconcat ("https://", uri + 9, NULL);
+			proto = "https://";
 		} else {
-			priv->uri = g_strconcat ("http://", uri + 9, NULL);
+			proto = "http://";
 		}
-	} else {		
+
+		priv->uri = g_strconcat (proto, uri + 9, NULL);
+
+	} else {
+
 		priv->uri = g_strdup (uri);
 	} 
-		
+
+	/* remove trailing slashes */
+	len = strlen (priv->uri);
+	while (len--) {
+		if (priv->uri[len] == '/') {
+			priv->uri[len] = '\0';
+		} else {
+			break;
+		}
+	}
+
 	if (priv->cache == NULL) {
 		priv->cache = e_cal_backend_cache_new (priv->uri, E_CAL_SOURCE_TYPE_EVENT);
 
@@ -1530,7 +1763,7 @@ caldav_do_open (ECalBackendSync *backend,
 
 	if (priv->mode == CAL_MODE_REMOTE) {
 		/* set forward proxy */
-		caldav_set_session_proxy(priv);
+		caldav_set_session_proxy (priv);
 	
 		status = caldav_server_open_calendar (cbdav);
 
@@ -1652,7 +1885,7 @@ caldav_create_object (ECalBackendSync  *backend,
 	if (online) {
 		CalDAVObject object;
 	
-		href = e_cal_component_gen_href (comp, priv->uri);	
+		href = e_cal_component_gen_href (comp);	
 	
 		object.href  = href;
 		object.etag  = NULL;
@@ -1737,7 +1970,6 @@ caldav_modify_object (ECalBackendSync  *backend,
 
 		status = caldav_server_put_object (cbdav, &object);
 
-		e_cal_component_set_href (comp, object.href);
 		e_cal_component_set_etag (comp, object.etag);
 		caldav_object_free (&object, FALSE);
 		
@@ -1942,7 +2174,7 @@ process_object (ECalBackendCalDAV   *cbdav,
 				object.etag  = g_strdup (etag);
 
 			} else {
-				object.href = e_cal_component_gen_href (ecomp, priv->uri);
+				object.href = e_cal_component_gen_href (ecomp);
 			}
 			
 			object.cdata = pack_cobj (cbdav, ecomp);
@@ -2581,6 +2813,8 @@ e_cal_backend_caldav_class_init (ECalBackendCalDAVClass *class)
 	backend_class = (ECalBackendClass *) class;
 	sync_class = (ECalBackendSyncClass *) class;
 
+	caldav_debug_init ();
+
 	parent_class = (ECalBackendSyncClass *) g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (ECalBackendCalDAVPrivate));
 
