@@ -31,7 +31,7 @@
 #include "e-cal-backend-contacts.h"
 
 #include <glib/gi18n-lib.h>
-#include <libedataserver/e-xml-hash-utils.h>
+#include "libedataserver/e-xml-hash-utils.h"
 #include <libecal/e-cal-recur.h>
 #include <libecal/e-cal-util.h>
 #include <libedata-cal/e-cal-backend-util.h>
@@ -39,7 +39,7 @@
 
 #include <libebook/e-book.h>
 
-#include <libedataserver/e-source-list.h>
+#include "libedataserver/e-source-list.h"
 
 static ECalBackendSyncClass *parent_class;
 
@@ -331,11 +331,13 @@ contacts_changed_cb (EBookView *book_view, const GList *contacts, gpointer user_
                 EContact *contact = E_CONTACT (i->data);
                 const char *uid = e_contact_get_const (contact, E_CONTACT_UID);
                 
-                /* If no date is set, remove from list of tracked contacts */                 
-                if (!e_contact_get (contact, E_CONTACT_BIRTH_DATE) &&
-                    !e_contact_get (contact, E_CONTACT_ANNIVERSARY)) {
-                        g_hash_table_remove (cbc->priv->tracked_contacts, (char *)uid);
-                } else {
+                /* Because this is a change of contact, then always remove old tracked data
+		   and if possible, add with (possibly) new values.
+		*/
+		g_hash_table_remove (cbc->priv->tracked_contacts, (char *)uid);
+
+                if (e_contact_get (contact, E_CONTACT_BIRTH_DATE) ||
+                    e_contact_get (contact, E_CONTACT_ANNIVERSARY)) {
                         ContactRecord *cr = contact_record_new (cbc, contact);
                         g_hash_table_insert (cbc->priv->tracked_contacts, g_strdup (uid), cr);
                 }
