@@ -930,10 +930,12 @@ camel_folder_summary_add_from_header(CamelFolderSummary *s, struct _camel_header
 CamelMessageInfo *
 camel_folder_summary_add_from_parser(CamelFolderSummary *s, CamelMimeParser *mp)
 {
+	CamelMessageInfo *info;
+
 	g_return_val_if_fail (CAMEL_IS_FOLDER_SUMMARY (s), NULL);
 	g_return_val_if_fail (CAMEL_IS_MIME_PARSER (mp), NULL);
 
-	CamelMessageInfo *info = camel_folder_summary_info_new_from_parser(s, mp);
+	info = camel_folder_summary_info_new_from_parser(s, mp);
 
 	camel_folder_summary_add(s, info);
 
