@@ -24,15 +24,15 @@
 #include <config.h>
 #endif
 
+#include <errno.h>
+#include <fcntl.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/types.h>
 #include <unistd.h>
-#include <fcntl.h>
-#include <errno.h>
 
-#include "libedataserver/e-msgport.h"
+#include <libedataserver/e-msgport.h>
 
 #include "camel-block-file.h"
 #include "camel-partition-table.h"
