@@ -29,12 +29,16 @@
 #endif
 
 #include <string.h>
+
+#include <glib.h>
+#include <glib/gi18n-lib.h>
 #include <gmodule.h>
+
 #include "camel-provider.h"
+#include "camel-sasl.h"
 #include "camel-session.h"
 #include "camel-url.h"
-#include "camel-sasl.h"
-#include "camel-i18n.h"
+
 #include "camel-groupwise-store.h"
 #include "camel-groupwise-transport.h"
 
@@ -50,18 +54,18 @@ CamelProviderConfEntry groupwise_conf_entries[] = {
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "mailcheck", NULL,
 	  N_("Checking for new mail") },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "check_all", NULL,
-	  N_("Check for new messages in all folders"), "1" },
+	  N_("C_heck for new messages in all folders"), "1" },
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "general", NULL, N_("Options") },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "filter", NULL,
-	  N_("Apply filters to new messages in Inbox on this server"), "0" },
+	  N_("_Apply filters to new messages in Inbox on this server"), "0" },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "filter_junk", NULL,
-	  N_("Check new messages for Junk contents"), "0" },
+	  N_("Check new messages for J_unk contents"), "0" },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "filter_junk_inbox", "filter_junk",
-	  N_("Only check for Junk messages in the INBOX folder"), "0" },
+	  N_("Only check for Junk messages in the IN_BOX folder"), "0" },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "sync_offline", NULL,
-	  N_("Automatically synchronize account locally"), "0" },
+	  N_("Automatically synchroni_ze account locally"), "0" },
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 
 	/* extra GroupWise  configuration settings */
