@@ -23,22 +23,21 @@
 #include <config.h>
 #endif
 
-#include <unistd.h>
 #include <ctype.h>
-#include <string.h>
 #include <errno.h>
 #include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
 
-#include "camel-imap-store-summary.h"
+#include <libedataserver/md5-utils.h>
+#include <libedataserver/e-memory.h>
 
 #include "camel-file-utils.h"
-
-#include "libedataserver/md5-utils.h"
-#include "libedataserver/e-memory.h"
-
 #include "camel-private.h"
-#include "camel-utf8.h"
 #include "camel-store.h"
+#include "camel-utf8.h"
+
+#include "camel-imap-store-summary.h"
 
 #define d(x)
 #define io(x)			/* io debug */
