@@ -23,11 +23,6 @@
 #ifndef CAMEL_LOCAL_STORE_H
 #define CAMEL_LOCAL_STORE_H 1
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus }*/
-
 #include "camel-store.h"
 
 #define CAMEL_LOCAL_STORE_TYPE     (camel_local_store_get_type ())
@@ -35,6 +30,8 @@ extern "C" {
 #define CAMEL_LOCAL_STORE_CLASS(k) (CAMEL_CHECK_CLASS_CAST ((k), CAMEL_LOCAL_STORE_TYPE, CamelLocalStoreClass))
 #define CAMEL_IS_LOCAL_STORE(o)    (CAMEL_CHECK_TYPE((o), CAMEL_LOCAL_STORE_TYPE))
 
+G_BEGIN_DECLS
+
 typedef struct {
 	CamelStore parent_object;	
 
@@ -56,9 +53,7 @@ const gchar *camel_local_store_get_toplevel_dir (CamelLocalStore *store);
 #define camel_local_store_get_full_path(ls, name) ((CamelLocalStoreClass *)((CamelObject *)ls)->klass)->get_full_path((CamelLocalStore *)ls, name)
 #define camel_local_store_get_meta_path(ls, name, ext) ((CamelLocalStoreClass *)((CamelObject *)ls)->klass)->get_meta_path((CamelLocalStore *)ls, name, ext)
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* CAMEL_LOCAL_STORE_H */
 
