@@ -23,22 +23,21 @@
 #include <config.h>
 #endif
 
-#include <unistd.h>
 #include <ctype.h>
-#include <string.h>
 #include <errno.h>
 #include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
 
-#include "camel-nntp-store-summary.h"
+#include <libedataserver/md5-utils.h>
+#include <libedataserver/e-memory.h>
 
 #include "camel-file-utils.h"
-
-#include "libedataserver/md5-utils.h"
-#include "libedataserver/e-memory.h"
-
 #include "camel-private.h"
 #include "camel-utf8.h"
 
+#include "camel-nntp-store-summary.h"
+
 #define d(x)
 #define io(x)			/* io debug */
 
@@ -249,7 +248,7 @@ camel_nntp_store_summary_path_to_full (CamelNNTPStoreSummary *s, const char *pat
 			} else {
 				if (c == '/')
 					c = dir_sep;
-				camel_utf8_putc(&f, c);
+				camel_utf8_putc((unsigned char **) &f, c);
 			}
 			break;
 		case 1:
@@ -259,11 +258,11 @@ camel_nntp_store_summary_path_to_full (CamelNNTPStoreSummary *s, const char *pat
 		case 2:
 			state = 0;
 			v |= hexnib (c);
-			camel_utf8_putc (&f, v);
+			camel_utf8_putc ((unsigned char **) &f, v);
 			break;
 		}
 	}
-	camel_utf8_putc (&f, c);
+	camel_utf8_putc ((unsigned char **) &f, c);
 	
 	/* merge old path part if required */
 	f = camel_utf8_utf7 (full);
