@@ -202,13 +202,13 @@ e_source_new_from_xml_node (xmlNodePtr node)
 	ESource *source;
 	xmlChar *uid;
 
-	uid = xmlGetProp (node, "uid");
+	uid = xmlGetProp (node, (xmlChar*)"uid");
 	if (uid == NULL)
 		return NULL;
 
 	source = g_object_new (e_source_get_type (), NULL);
 
-	source->priv->uid = g_strdup (uid);
+	source->priv->uid = g_strdup ((char*)uid);
 	xmlFree (uid);
 
 	if (e_source_update_from_xml_node (source, node, NULL))
@@ -255,14 +255,14 @@ import_properties (ESource *source,
 	for (prop_node = prop_root->children; prop_node; prop_node = prop_node->next) {
 		xmlChar *name, *value;
 
-		if (!prop_node->name || strcmp (prop_node->name, "property"))
+		if (!prop_node->name || strcmp ((char*)prop_node->name, "property"))
 			continue;
 
-		name = xmlGetProp (prop_node, "name");
-		value = xmlGetProp (prop_node, "value");
+		name = xmlGetProp (prop_node, (xmlChar*)"name");
+		value = xmlGetProp (prop_node, (xmlChar*)"value");
 
 		if (name && value)
-			g_hash_table_insert (priv->properties, g_strdup (name), g_strdup (value));
+			g_hash_table_insert (priv->properties, g_strdup ((char*)name), g_strdup ((char*)value));
 
 		if (name)
 			xmlFree (name);
@@ -322,11 +322,11 @@ e_source_update_from_xml_node (ESource *source,
 	gboolean retval = FALSE;
 	gboolean changed = FALSE;
 
-	name = xmlGetProp (node, "name");
-	relative_uri = xmlGetProp (node, "relative_uri");
-	absolute_uri = xmlGetProp (node, "uri");
-	color_spec = xmlGetProp (node, "color_spec");
-	color = xmlGetProp (node, "color");  /* obsolete */
+	name = xmlGetProp (node, (xmlChar*)"name");
+	relative_uri = xmlGetProp (node, (xmlChar*)"relative_uri");
+	absolute_uri = xmlGetProp (node, (xmlChar*)"uri");
+	color_spec = xmlGetProp (node, (xmlChar*)"color_spec");
+	color = xmlGetProp (node, (xmlChar*)"color");  /* obsolete */
 
 	if (name == NULL || (relative_uri == NULL && absolute_uri == NULL))
 		goto done;
@@ -335,28 +335,28 @@ e_source_update_from_xml_node (ESource *source,
 		goto done;
 
 	if (source->priv->name == NULL
-	    || strcmp (name, source->priv->name) != 0
+	    || strcmp ((char*)name, source->priv->name) != 0
 	    || source->priv->relative_uri == NULL
 	    || relative_uri != NULL
-	    || strcmp (relative_uri, source->priv->relative_uri) != 0) {
+	    || strcmp ((char*)relative_uri, source->priv->relative_uri) != 0) {
 		g_free (source->priv->name);
-		source->priv->name = g_strdup (name);
+		source->priv->name = g_strdup ((char*)name);
 
 		g_free (source->priv->relative_uri);
-		source->priv->relative_uri = g_strdup (relative_uri);
+		source->priv->relative_uri = g_strdup ((char*)relative_uri);
 
 		changed = TRUE;
 	}
 
 	if (absolute_uri != NULL) {
 		g_free (source->priv->absolute_uri);
-		source->priv->absolute_uri = g_strdup (absolute_uri);
+		source->priv->absolute_uri = g_strdup ((char*)absolute_uri);
 		changed = TRUE;
 	}
 
 	if (color == NULL) {
 		/* It is okay for color_spec to be NULL. */
-		changed |= set_color_spec (source, color_spec);
+		changed |= set_color_spec (source, (char*)color_spec);
 	} else {
 		gchar buffer[8];
 		g_snprintf (buffer, sizeof (buffer), "#%s", color);
@@ -374,7 +374,7 @@ e_source_update_from_xml_node (ESource *source,
 		if (!node->name)
 			continue;
 
-		if (!strcmp (node->name, "properties")) {
+		if (!strcmp ((char*)node->name, "properties")) {
 			GHashTable *temp = source->priv->properties;
 			source->priv->properties = g_hash_table_new_full (g_str_hash, g_str_equal,
 									  g_free, g_free);
@@ -422,13 +422,13 @@ e_source_update_from_xml_node (ESource *source,
 char *
 e_source_uid_from_xml_node (xmlNodePtr node)
 {
-	xmlChar *uid = xmlGetProp (node, "uid");
+	xmlChar *uid = xmlGetProp (node, (xmlChar*)"uid");
 	char *retval;
 
 	if (uid == NULL)
 		return NULL;
 
-	retval = g_strdup (uid);
+	retval = g_strdup ((char*)uid);
 	xmlFree (uid);
 	return retval;
 }
@@ -727,13 +727,13 @@ e_source_get_uri (ESource *source)
 
 
 static void
-property_dump_cb (const gchar *key, const gchar *value, xmlNodePtr root)
+property_dump_cb (const xmlChar *key, const xmlChar *value, xmlNodePtr root)
 {
 	xmlNodePtr node;
 
-	node = xmlNewChild (root, NULL, "property", NULL);
-	xmlSetProp (node, "name", key);
-	xmlSetProp (node, "value", value);
+	node = xmlNewChild (root, NULL, (xmlChar*)"property", NULL);
+	xmlSetProp (node, (xmlChar*)"name", key);
+	xmlSetProp (node, (xmlChar*)"value", value);
 }
 
 
@@ -748,26 +748,26 @@ dump_common_to_xml_node (ESource *source,
 	priv = source->priv;
 
 	if (parent_node)
-		node = xmlNewChild (parent_node, NULL, "source", NULL);
+		node = xmlNewChild (parent_node, NULL, (xmlChar*)"source", NULL);
 	else
-		node = xmlNewNode (NULL, "source");
+		node = xmlNewNode (NULL, (xmlChar*)"source");
 
-	xmlSetProp (node, "uid", e_source_peek_uid (source));
-	xmlSetProp (node, "name", e_source_peek_name (source));
+	xmlSetProp (node, (xmlChar*)"uid", (xmlChar*)e_source_peek_uid (source));
+	xmlSetProp (node, (xmlChar*)"name", (xmlChar*)e_source_peek_name (source));
 	abs_uri = e_source_peek_absolute_uri (source);
 	relative_uri = e_source_peek_relative_uri (source);
 	if (abs_uri)
-		xmlSetProp (node, "uri", abs_uri);
+		xmlSetProp (node, (xmlChar*)"uri", (xmlChar*)abs_uri);
 	if (relative_uri)
-		xmlSetProp (node, "relative_uri", relative_uri);
+		xmlSetProp (node, (xmlChar*)"relative_uri", (xmlChar*)relative_uri);
 
 	if (priv->color_spec != NULL)
-		xmlSetProp (node, "color_spec", priv->color_spec);
+		xmlSetProp (node, (xmlChar*)"color_spec", (xmlChar*)priv->color_spec);
 
 	if (g_hash_table_size (priv->properties) != 0) {
 		xmlNodePtr properties_node;
 
-		properties_node = xmlNewChild (node, NULL, "properties", NULL);
+		properties_node = xmlNewChild (node, NULL, (xmlChar*)"properties", NULL);
 		g_hash_table_foreach (priv->properties, (GHFunc) property_dump_cb, properties_node);
 	}
 
@@ -797,13 +797,13 @@ e_source_to_standalone_xml (ESource *source)
 
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
 
-	doc = xmlNewDoc ("1.0");
+	doc = xmlNewDoc ((xmlChar*)"1.0");
 	node = dump_common_to_xml_node (source, NULL);
 
 	xmlDocSetRootElement (doc, node);
 
 	uri = e_source_get_uri (source);
-	xmlSetProp (node, "uri", uri);
+	xmlSetProp (node, (xmlChar*)"uri", (xmlChar*)uri);
 	g_free (uri);
 
 	xmlDocDumpMemory (doc, &xml_buffer, &xml_buffer_size);
@@ -825,12 +825,12 @@ e_source_new_from_standalone_xml (const char *xml)
 	xmlNodePtr root;
 	ESource *source;
 
-	doc = xmlParseDoc ((char *) xml);
+	doc = xmlParseDoc ((xmlChar*)xml);
 	if (doc == NULL)
 		return NULL;
 
 	root = doc->children;
-	if (strcmp (root->name, "source") != 0)
+	if (strcmp ((char*)root->name, "source") != 0)
 		return NULL;
 
 	source = e_source_new_from_xml_node (root);
