@@ -43,7 +43,7 @@ e_gw_proxy_construct_proxy_access_list (SoupSoapParameter *param, GList **proxy_
 			subparam = soup_soap_parameter_get_next_child_by_name (subparam, "entry")) {
 
 		proxyHandler *aclInstance;
-		aclInstance = (proxyHandler *) malloc(sizeof(proxyHandler));
+		aclInstance = (proxyHandler *) g_malloc0 (sizeof(proxyHandler));
 		aclInstance->permissions = 0;
 		aclInstance->flags = 0;
 		type_param = soup_soap_parameter_get_first_child_by_name (subparam, "email");
@@ -322,8 +322,15 @@ void
 e_gw_proxy_form_modify_proxy_msg (SoupSoapMessage *msg, proxyHandler *new_proxy)
 {
 	soup_soap_message_start_element (msg, "updates", NULL, NULL);
-
+	
+	soup_soap_message_start_element (msg, "delete", NULL, NULL);
+	soup_soap_message_end_element (msg);
+	
+	soup_soap_message_start_element (msg, "add", NULL, NULL);
 	e_gw_proxy_form_soap_request_from_proxyHandler (msg, new_proxy);
+	soup_soap_message_end_element (msg);
+	
+	soup_soap_message_end_element (msg);
 }
 
 void
